==> cscec5b-fbxt-api-3.0.1-20211203.042743-20-sources.jar: com/ejianc/business/fbxt/grap/vo/AssignmentInfoVO.java <==
package com.ejianc.business.fbxt.grap.vo;


import com.ejianc.framework.skeleton.template.BaseVO;
import org.elasticsearch.search.DocValueFormat;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;


public class AssignmentInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    //清单编码
    private String pkBookInfo;
    //主表id
    private String pkBookId;
    //清单名称
    private String infoName;
    //单位
    private String infoUnit;
    //累计完成量
    private BigDecimal infoCount;
    //数量
    private BigDecimal infoNumber;
    //施工部位
    private String infoSite;
    //清单编码
    private String infoCode;

    private BigDecimal price; // 无税单价
    private BigDecimal mny; // 金额
    //参照清单主键
    private String infoId;

    public String getInfoCode() {
        return infoCode;
    }

    public void setInfoCode(String infoCode) {
        this.infoCode = infoCode;
    }

    public String getInfoId() {
        return infoId;
    }

    public void setInfoId(String infoId) {
        this.infoId = infoId;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getPkBookInfo() {
        return pkBookInfo;
    }

    public void setPkBookInfo(String pkBookInfo) {
        this.pkBookInfo = pkBookInfo;
    }

    public String getPkBookId() {
        return pkBookId;
    }

    public void setPkBookId(String pkBookId) {
        this.pkBookId = pkBookId;
    }

    public String getInfoName() {
        return infoName;
    }

    public void setInfoName(String infoName) {
        this.infoName = infoName;
    }

    public String getInfoUnit() {
        return infoUnit;
    }

    public void setInfoUnit(String infoUnit) {
        this.infoUnit = infoUnit;
    }

    public BigDecimal getInfoCount() {
        return infoCount;
    }

    public void setInfoCount(BigDecimal infoCount) {
        this.infoCount = infoCount;
    }

    public BigDecimal getInfoNumber() {
        return infoNumber;
    }

    public void setInfoNumber(BigDecimal infoNumber) {
        this.infoNumber = infoNumber;
    }

    public String getInfoSite() {
        return infoSite;
    }

    public void setInfoSite(String infoSite) {
        this.infoSite = infoSite;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
}

==> cscec5b-fbxt-api-3.0.1-20220228.021628-49-sources.jar: com/ejianc/business/fbxt/grap/vo/AssignmentInfoVO.java <==
package com.ejianc.business.fbxt.grap.vo;


import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import org.elasticsearch.search.DocValueFormat;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;


public class AssignmentInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    //清单编码
    private String pkBookInfo;
    //主表id
    private String pkBookId;
    //清单名称
    private String infoName;
    //单位
    private String infoUnit;
    //累计完成量
    private BigDecimal infoCount;
    //数量
    private BigDecimal infoNumber;
    //施工部位
    private String infoSite;
    //清单编码
    private String infoCode;
    //清单量
    private String infoAmount;

    private BigDecimal price; // 无税单价
    private BigDecimal mny; // 金额
    //参照清单主键
    private String infoId;

    public String getInfoAmount() {
        return infoAmount;
    }

    public void setInfoAmount(String infoAmount) {
        this.infoAmount = infoAmount;
    }

    private java.math.BigDecimal infoProjectNumber;//项目部审核量

    public java.math.BigDecimal getInfoProjectNumber() {
        return infoProjectNumber;
    }

    public void setInfoProjectNumber(java.math.BigDecimal infoProjectNumber) {
        this.infoProjectNumber = infoProjectNumber;
    }

    public String getInfoCode() {
        return infoCode;
    }

    public void setInfoCode(String infoCode) {
        this.infoCode = infoCode;
    }

    public String getInfoId() {
        return infoId;
    }

    public void setInfoId(String infoId) {
        this.infoId = infoId;
    }

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getPkBookInfo() {
        return pkBookInfo;
    }

    public void setPkBookInfo(String pkBookInfo) {
        this.pkBookInfo = pkBookInfo;
    }

    public String getPkBookId() {
        return pkBookId;
    }

    public void setPkBookId(String pkBookId) {
        this.pkBookId = pkBookId;
    }

    public String getInfoName() {
        return infoName;
    }

    public void setInfoName(String infoName) {
        this.infoName = infoName;
    }

    public String getInfoUnit() {
        return infoUnit;
    }

    public void setInfoUnit(String infoUnit) {
        this.infoUnit = infoUnit;
    }

    public BigDecimal getInfoCount() {
        return infoCount;
    }

    public void setInfoCount(BigDecimal infoCount) {
        this.infoCount = infoCount;
    }

    public BigDecimal getInfoNumber() {
        return infoNumber;
    }

    public void setInfoNumber(BigDecimal infoNumber) {
        this.infoNumber = infoNumber;
    }

    public String getInfoSite() {
        return infoSite;
    }

    public void setInfoSite(String infoSite) {
        this.infoSite = infoSite;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
}
